@@ -30,53 +30,53 @@ from airflow.providers.amazon.aws.operators.emr import (
 )
 from airflow.providers.amazon.aws.sensors.emr import EmrJobFlowSensor, EmrStepSensor
 
-JOB_FLOW_ROLE = os.getenv('EMR_JOB_FLOW_ROLE', 'EMR_EC2_DefaultRole')
-SERVICE_ROLE = os.getenv('EMR_SERVICE_ROLE', 'EMR_DefaultRole')
+JOB_FLOW_ROLE = os.getenv("EMR_JOB_FLOW_ROLE", "EMR_EC2_DefaultRole")
+SERVICE_ROLE = os.getenv("EMR_SERVICE_ROLE", "EMR_DefaultRole")
 
 # [START howto_operator_emr_steps_config]
 SPARK_STEPS = [
     {
-        'Name': 'calculate_pi',
-        'ActionOnFailure': 'CONTINUE',
-        'HadoopJarStep': {
-            'Jar': 'command-runner.jar',
-            'Args': ['/usr/lib/spark/bin/run-example', 'SparkPi', '10'],
+        "Name": "calculate_pi",
+        "ActionOnFailure": "CONTINUE",
+        "HadoopJarStep": {
+            "Jar": "command-runner.jar",
+            "Args": ["/usr/lib/spark/bin/run-example", "SparkPi", "10"],
         },
     }
 ]
 
 JOB_FLOW_OVERRIDES = {
-    'Name': 'PiCalc',
-    'ReleaseLabel': 'emr-5.29.0',
-    'Applications': [{'Name': 'Spark'}],
-    'Instances': {
-        'InstanceGroups': [
+    "Name": "PiCalc",
+    "ReleaseLabel": "emr-5.29.0",
+    "Applications": [{"Name": "Spark"}],
+    "Instances": {
+        "InstanceGroups": [
             {
-                'Name': 'Primary node',
-                'Market': 'ON_DEMAND',
-                'InstanceRole': 'MASTER',
-                'InstanceType': 'm5.xlarge',
-                'InstanceCount': 1,
+                "Name": "Primary node",
+                "Market": "ON_DEMAND",
+                "InstanceRole": "MASTER",
+                "InstanceType": "m5.xlarge",
+                "InstanceCount": 1,
             },
         ],
-        'KeepJobFlowAliveWhenNoSteps': False,
-        'TerminationProtected': False,
+        "KeepJobFlowAliveWhenNoSteps": False,
+        "TerminationProtected": False,
     },
-    'Steps': SPARK_STEPS,
-    'JobFlowRole': JOB_FLOW_ROLE,
-    'ServiceRole': SERVICE_ROLE,
+    "Steps": SPARK_STEPS,
+    "JobFlowRole": JOB_FLOW_ROLE,
+    "ServiceRole": SERVICE_ROLE,
 }
 # [END howto_operator_emr_steps_config]
 
 with DAG(
-    dag_id='example_emr',
+    dag_id="example_emr",
     start_date=datetime(2021, 1, 1),
-    tags=['example'],
+    tags=["example"],
     catchup=False,
 ) as dag:
     # [START howto_operator_emr_create_job_flow]
     job_flow_creator = EmrCreateJobFlowOperator(
-        task_id='create_job_flow',
+        task_id="create_job_flow",
         job_flow_overrides=JOB_FLOW_OVERRIDES,
     )
     # [END howto_operator_emr_create_job_flow]
@@ -84,18 +84,18 @@ with DAG(
     job_flow_id = job_flow_creator.output
 
     # [START howto_sensor_emr_job_flow]
-    job_sensor = EmrJobFlowSensor(task_id='check_job_flow', job_flow_id=job_flow_id)
+    job_sensor = EmrJobFlowSensor(task_id="check_job_flow", job_flow_id=job_flow_id)
     # [END howto_sensor_emr_job_flow]
 
     # [START howto_operator_emr_modify_cluster]
     cluster_modifier = EmrModifyClusterOperator(
-        task_id='modify_cluster', cluster_id=job_flow_id, step_concurrency_level=1
+        task_id="modify_cluster", cluster_id=job_flow_id, step_concurrency_level=1
     )
     # [END howto_operator_emr_modify_cluster]
 
     # [START howto_operator_emr_add_steps]
     step_adder = EmrAddStepsOperator(
-        task_id='add_steps',
+        task_id="add_steps",
         job_flow_id=job_flow_id,
         steps=SPARK_STEPS,
     )
@@ -103,7 +103,7 @@ with DAG(
 
     # [START howto_sensor_emr_step]
     step_checker = EmrStepSensor(
-        task_id='watch_step',
+        task_id="watch_step",
         job_flow_id=job_flow_id,
         step_id="{{ task_instance.xcom_pull(task_ids='add_steps', key='return_value')[0] }}",
     )
@@ -111,7 +111,7 @@ with DAG(
 
     # [START howto_operator_emr_terminate_job_flow]
     cluster_remover = EmrTerminateJobFlowOperator(
-        task_id='remove_cluster',
+        task_id="remove_cluster",
         job_flow_id=job_flow_id,
     )
     # [END howto_operator_emr_terminate_job_flow]
