@@ -58,7 +58,6 @@ class ElastiCacheReplicationGroupHook(AwsBaseHook):
 
         :param config: Configuration for creating the replication group
         :return: Response from ElastiCache create replication group API
-        :rtype: dict
         """
         return self.conn.create_replication_group(**config)
 
@@ -68,7 +67,6 @@ class ElastiCacheReplicationGroupHook(AwsBaseHook):
 
         :param replication_group_id: ID of replication group to delete
         :return: Response from ElastiCache delete replication group API
-        :rtype: dict
         """
         return self.conn.delete_replication_group(ReplicationGroupId=replication_group_id)
 
@@ -78,7 +76,6 @@ class ElastiCacheReplicationGroupHook(AwsBaseHook):
 
         :param replication_group_id: ID of replication group to describe
         :return: Response from ElastiCache describe replication group API
-        :rtype: dict
         """
         return self.conn.describe_replication_groups(ReplicationGroupId=replication_group_id)
 
@@ -88,9 +85,8 @@ class ElastiCacheReplicationGroupHook(AwsBaseHook):
 
         :param replication_group_id: ID of replication group to check for status
         :return: Current status of replication group
-        :rtype: str
         """
-        return self.describe_replication_group(replication_group_id)['ReplicationGroups'][0]['Status']
+        return self.describe_replication_group(replication_group_id)["ReplicationGroups"][0]["Status"]
 
     def is_replication_group_available(self, replication_group_id: str) -> bool:
         """
@@ -98,9 +94,8 @@ class ElastiCacheReplicationGroupHook(AwsBaseHook):
 
         :param replication_group_id: ID of replication group to check for availability
         :return: True if available else False
-        :rtype: bool
         """
-        return self.get_replication_group_status(replication_group_id) == 'available'
+        return self.get_replication_group_status(replication_group_id) == "available"
 
     def wait_for_availability(
         self,
@@ -108,7 +103,7 @@ class ElastiCacheReplicationGroupHook(AwsBaseHook):
         initial_sleep_time: float | None = None,
         exponential_back_off_factor: float | None = None,
         max_retries: int | None = None,
-    ):
+    ) -> bool:
         """
         Check if replication group is available or not by performing a describe over it
 
@@ -120,13 +115,12 @@ class ElastiCacheReplicationGroupHook(AwsBaseHook):
         :param max_retries: Max retries for checking availability of replication group
             If this is not supplied then this is defaulted to class level value
         :return: True if replication is available else False
-        :rtype: bool
         """
         sleep_time = initial_sleep_time or self.initial_poke_interval
         exponential_back_off_factor = exponential_back_off_factor or self.exponential_back_off_factor
         max_retries = max_retries or self.max_retries
         num_tries = 0
-        status = 'not-found'
+        status = "not-found"
         stop_poking = False
 
         while not stop_poking and num_tries <= max_retries:
@@ -134,7 +128,7 @@ class ElastiCacheReplicationGroupHook(AwsBaseHook):
             stop_poking = status in self.TERMINAL_STATES
 
             self.log.info(
-                'Current status of replication group with ID %s is %s', replication_group_id, status
+                "Current status of replication group with ID %s is %s", replication_group_id, status
             )
 
             if not stop_poking:
@@ -144,13 +138,13 @@ class ElastiCacheReplicationGroupHook(AwsBaseHook):
                 if num_tries > max_retries:
                     break
 
-                self.log.info('Poke retry %s. Sleep time %s seconds. Sleeping...', num_tries, sleep_time)
+                self.log.info("Poke retry %s. Sleep time %s seconds. Sleeping...", num_tries, sleep_time)
 
                 sleep(sleep_time)
 
                 sleep_time *= exponential_back_off_factor
 
-        if status != 'available':
+        if status != "available":
             self.log.warning('Replication group is not available. Current status is "%s"', status)
 
             return False
@@ -175,7 +169,6 @@ class ElastiCacheReplicationGroupHook(AwsBaseHook):
         :param max_retries: Max retries for checking availability of replication group
             If this is not supplied then this is defaulted to class level value
         :return: Response from ElastiCache delete replication group API and flag to identify if deleted or not
-        :rtype: (dict, bool)
         """
         deleted = False
         sleep_time = initial_sleep_time or self.initial_poke_interval
@@ -189,12 +182,12 @@ class ElastiCacheReplicationGroupHook(AwsBaseHook):
                 status = self.get_replication_group_status(replication_group_id=replication_group_id)
 
                 self.log.info(
-                    'Current status of replication group with ID %s is %s', replication_group_id, status
+                    "Current status of replication group with ID %s is %s", replication_group_id, status
                 )
 
                 # Can only delete if status is `available`
                 # Status becomes `deleting` after this call so this will only run once
-                if status == 'available':
+                if status == "available":
                     self.log.info("Initiating delete and then wait for it to finish")
 
                     response = self.delete_replication_group(replication_group_id=replication_group_id)
@@ -214,9 +207,9 @@ class ElastiCacheReplicationGroupHook(AwsBaseHook):
                 # modifying - Replication group <replication_group_id> has status deleting which is not valid
                 #             for deletion.
 
-                message = exp.response['Error']['Message']
+                message = exp.response["Error"]["Message"]
 
-                self.log.warning('Received error message from AWS ElastiCache API : %s', message)
+                self.log.warning("Received error message from AWS ElastiCache API : %s", message)
 
             if not deleted:
                 num_tries += 1
@@ -225,7 +218,7 @@ class ElastiCacheReplicationGroupHook(AwsBaseHook):
                 if num_tries > max_retries:
                     break
 
-                self.log.info('Poke retry %s. Sleep time %s seconds. Sleeping...', num_tries, sleep_time)
+                self.log.info("Poke retry %s. Sleep time %s seconds. Sleeping...", num_tries, sleep_time)
 
                 sleep(sleep_time)
 
@@ -239,7 +232,7 @@ class ElastiCacheReplicationGroupHook(AwsBaseHook):
         initial_sleep_time: float | None = None,
         exponential_back_off_factor: float | None = None,
         max_retries: int | None = None,
-    ):
+    ) -> dict:
         """
         Delete a replication group ensuring it is either deleted or can't be deleted
 
@@ -251,10 +244,9 @@ class ElastiCacheReplicationGroupHook(AwsBaseHook):
         :param max_retries: Max retries for checking availability of replication group
             If this is not supplied then this is defaulted to class level value
         :return: Response from ElastiCache delete replication group API
-        :rtype: dict
         :raises AirflowException: If replication group is not deleted
         """
-        self.log.info('Deleting replication group with ID %s', replication_group_id)
+        self.log.info("Deleting replication group with ID %s", replication_group_id)
 
         response, deleted = self.wait_for_deletion(
             replication_group_id=replication_group_id,
