@@ -17,6 +17,7 @@
 # under the License.
 from __future__ import annotations
 
+import json
 import warnings
 from time import sleep
 from typing import Any, Callable
@@ -30,8 +31,11 @@ from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
 
 class EmrHook(AwsBaseHook):
     """
-    Interact with AWS EMR. emr_conn_id is only necessary for using the
-    create_job_flow method.
+    Interact with Amazon Elastic MapReduce Service.
+
+    :param emr_conn_id: :ref:`Amazon Elastic MapReduce Connection <howto/connection:emr>`.
+        This attribute is only necessary when using
+        the :meth:`~airflow.providers.amazon.aws.hooks.emr.EmrHook.create_job_flow` method.
 
     Additional arguments (such as ``aws_conn_id``) may be specified and
     are passed down to the underlying AwsBaseHook.
@@ -40,13 +44,13 @@ class EmrHook(AwsBaseHook):
         :class:`~airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
     """
 
-    conn_name_attr = 'emr_conn_id'
-    default_conn_name = 'emr_default'
-    conn_type = 'emr'
-    hook_name = 'Amazon Elastic MapReduce'
+    conn_name_attr = "emr_conn_id"
+    default_conn_name = "emr_default"
+    conn_type = "emr"
+    hook_name = "Amazon Elastic MapReduce"
 
-    def __init__(self, emr_conn_id: str = default_conn_name, *args, **kwargs) -> None:
-        self.emr_conn_id: str = emr_conn_id
+    def __init__(self, emr_conn_id: str | None = default_conn_name, *args, **kwargs) -> None:
+        self.emr_conn_id = emr_conn_id
         kwargs["client_type"] = "emr"
         super().__init__(*args, **kwargs)
 
@@ -62,37 +66,112 @@ class EmrHook(AwsBaseHook):
         response = self.get_conn().list_clusters(ClusterStates=cluster_states)
 
         matching_clusters = list(
-            filter(lambda cluster: cluster['Name'] == emr_cluster_name, response['Clusters'])
+            filter(lambda cluster: cluster["Name"] == emr_cluster_name, response["Clusters"])
         )
 
         if len(matching_clusters) == 1:
-            cluster_id = matching_clusters[0]['Id']
-            self.log.info('Found cluster name = %s id = %s', emr_cluster_name, cluster_id)
+            cluster_id = matching_clusters[0]["Id"]
+            self.log.info("Found cluster name = %s id = %s", emr_cluster_name, cluster_id)
             return cluster_id
         elif len(matching_clusters) > 1:
-            raise AirflowException(f'More than one cluster found for name {emr_cluster_name}')
+            raise AirflowException(f"More than one cluster found for name {emr_cluster_name}")
         else:
-            self.log.info('No cluster found for name %s', emr_cluster_name)
+            self.log.info("No cluster found for name %s", emr_cluster_name)
             return None
 
     def create_job_flow(self, job_flow_overrides: dict[str, Any]) -> dict[str, Any]:
         """
-        Creates a job flow using the config from the EMR connection.
-        Keys of the json extra hash may have the arguments of the boto3
-        run_job_flow method.
-        Overrides for this config may be passed as the job_flow_overrides.
+        Create and start running a new cluster (job flow).
+
+        This method uses ``EmrHook.emr_conn_id`` to receive the initial Amazon EMR cluster configuration.
+        If ``EmrHook.emr_conn_id`` is empty or the connection does not exist, then an empty initial
+        configuration is used.
+
+        :param job_flow_overrides: Is used to overwrite the parameters in the initial Amazon EMR configuration
+            cluster. The resulting configuration will be used in the boto3 emr client run_job_flow method.
+
+        .. seealso::
+            - :ref:`Amazon Elastic MapReduce Connection <howto/connection:emr>`
+            - `API RunJobFlow <https://docs.aws.amazon.com/emr/latest/APIReference/API_RunJobFlow.html>`_
+            - `boto3 emr client run_job_flow method <https://boto3.amazonaws.com/v1/documentation/\
+               api/latest/reference/services/emr.html#EMR.Client.run_job_flow>`_.
         """
-        try:
-            emr_conn = self.get_connection(self.emr_conn_id)
-            config = emr_conn.extra_dejson.copy()
-        except AirflowNotFoundException:
-            config = {}
+        config = {}
+        if self.emr_conn_id:
+            try:
+                emr_conn = self.get_connection(self.emr_conn_id)
+            except AirflowNotFoundException:
+                warnings.warn(
+                    f"Unable to find {self.hook_name} Connection ID {self.emr_conn_id!r}, "
+                    "using an empty initial configuration. If you want to get rid of this warning "
+                    "message please provide a valid `emr_conn_id` or set it to None.",
+                    UserWarning,
+                    stacklevel=2,
+                )
+            else:
+                if emr_conn.conn_type and emr_conn.conn_type != self.conn_type:
+                    warnings.warn(
+                        f"{self.hook_name} Connection expected connection type {self.conn_type!r}, "
+                        f"Connection {self.emr_conn_id!r} has conn_type={emr_conn.conn_type!r}. "
+                        f"This connection might not work correctly.",
+                        UserWarning,
+                        stacklevel=2,
+                    )
+                config = emr_conn.extra_dejson.copy()
         config.update(job_flow_overrides)
 
         response = self.get_conn().run_job_flow(**config)
 
         return response
 
+    def test_connection(self):
+        """
+        Return failed state for test Amazon Elastic MapReduce Connection (untestable).
+
+        We need to overwrite this method because this hook is based on
+        :class:`~airflow.providers.amazon.aws.hooks.base_aws.AwsGenericHook`,
+        otherwise it will try to test connection to AWS STS by using the default boto3 credential strategy.
+        """
+        msg = (
+            f"{self.hook_name!r} Airflow Connection cannot be tested, by design it stores "
+            f"only key/value pairs and does not make a connection to an external resource."
+        )
+        return False, msg
+
+    @staticmethod
+    def get_ui_field_behaviour() -> dict[str, Any]:
+        """Returns custom UI field behaviour for Amazon Elastic MapReduce Connection."""
+        return {
+            "hidden_fields": ["host", "schema", "port", "login", "password"],
+            "relabeling": {
+                "extra": "Run Job Flow Configuration",
+            },
+            "placeholders": {
+                "extra": json.dumps(
+                    {
+                        "Name": "MyClusterName",
+                        "ReleaseLabel": "emr-5.36.0",
+                        "Applications": [{"Name": "Spark"}],
+                        "Instances": {
+                            "InstanceGroups": [
+                                {
+                                    "Name": "Primary node",
+                                    "Market": "SPOT",
+                                    "InstanceRole": "MASTER",
+                                    "InstanceType": "m5.large",
+                                    "InstanceCount": 1,
+                                },
+                            ],
+                            "KeepJobFlowAliveWhenNoSteps": False,
+                            "TerminationProtected": False,
+                        },
+                        "StepConcurrencyLevel": 2,
+                    },
+                    indent=2,
+                ),
+            },
+        }
+
 
 class EmrServerlessHook(AwsBaseHook):
     """
@@ -105,14 +184,14 @@ class EmrServerlessHook(AwsBaseHook):
         :class:`~airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
     """
 
-    JOB_INTERMEDIATE_STATES = {'PENDING', 'RUNNING', 'SCHEDULED', 'SUBMITTED'}
-    JOB_FAILURE_STATES = {'FAILED', 'CANCELLING', 'CANCELLED'}
-    JOB_SUCCESS_STATES = {'SUCCESS'}
+    JOB_INTERMEDIATE_STATES = {"PENDING", "RUNNING", "SCHEDULED", "SUBMITTED"}
+    JOB_FAILURE_STATES = {"FAILED", "CANCELLING", "CANCELLED"}
+    JOB_SUCCESS_STATES = {"SUCCESS"}
     JOB_TERMINAL_STATES = JOB_SUCCESS_STATES.union(JOB_FAILURE_STATES)
 
-    APPLICATION_INTERMEDIATE_STATES = {'CREATING', 'STARTING', 'STOPPING'}
-    APPLICATION_FAILURE_STATES = {'STOPPED', 'TERMINATED'}
-    APPLICATION_SUCCESS_STATES = {'CREATED', 'STARTED'}
+    APPLICATION_INTERMEDIATE_STATES = {"CREATING", "STARTING", "STOPPING"}
+    APPLICATION_FAILURE_STATES = {"STOPPED", "TERMINATED"}
+    APPLICATION_SUCCESS_STATES = {"CREATED", "STARTED"}
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         kwargs["client_type"] = "emr-serverless"
@@ -156,14 +235,14 @@ class EmrServerlessHook(AwsBaseHook):
         state: str = self.get_state(response, parse_response)
         while state not in desired_state:
             if state in failure_states:
-                raise AirflowException(f'{object_type.title()} reached failure state {state}.')
+                raise AirflowException(f"{object_type.title()} reached failure state {state}.")
             if countdown >= check_interval_seconds:
                 countdown -= check_interval_seconds
-                self.log.info('Waiting for %s to be %s.', object_type.lower(), action.lower())
+                self.log.info("Waiting for %s to be %s.", object_type.lower(), action.lower())
                 sleep(check_interval_seconds)
                 state = self.get_state(get_state_callable(**get_state_args), parse_response)
             else:
-                message = f'{object_type.title()} still not {action.lower()} after the allocated time limit.'
+                message = f"{object_type.title()} still not {action.lower()} after the allocated time limit."
                 self.log.error(message)
                 raise RuntimeError(message)
 
@@ -226,14 +305,14 @@ class EmrContainerHook(AwsBaseHook):
             tags=tags or {},
         )
 
-        if response['ResponseMetadata']['HTTPStatusCode'] != 200:
-            raise AirflowException(f'Create EMR EKS Cluster failed: {response}')
+        if response["ResponseMetadata"]["HTTPStatusCode"] != 200:
+            raise AirflowException(f"Create EMR EKS Cluster failed: {response}")
         else:
             self.log.info(
                 "Create EMR EKS Cluster success - virtual cluster id %s",
-                response['id'],
+                response["id"],
             )
-            return response['id']
+            return response["id"]
 
     def submit_job(
         self,
@@ -276,15 +355,15 @@ class EmrContainerHook(AwsBaseHook):
 
         response = self.conn.start_job_run(**params)
 
-        if response['ResponseMetadata']['HTTPStatusCode'] != 200:
-            raise AirflowException(f'Start Job Run failed: {response}')
+        if response["ResponseMetadata"]["HTTPStatusCode"] != 200:
+            raise AirflowException(f"Start Job Run failed: {response}")
         else:
             self.log.info(
                 "Start Job Run success - Job Id %s and virtual cluster id %s",
-                response['id'],
-                response['virtualClusterId'],
+                response["id"],
+                response["virtualClusterId"],
             )
-            return response['id']
+            return response["id"]
 
     def get_job_failure_reason(self, job_id: str) -> str | None:
         """
@@ -301,13 +380,13 @@ class EmrContainerHook(AwsBaseHook):
                 virtualClusterId=self.virtual_cluster_id,
                 id=job_id,
             )
-            failure_reason = response['jobRun']['failureReason']
+            failure_reason = response["jobRun"]["failureReason"]
             state_details = response["jobRun"]["stateDetails"]
             reason = f"{failure_reason} - {state_details}"
         except KeyError:
-            self.log.error('Could not get status of the EMR on EKS job')
+            self.log.error("Could not get status of the EMR on EKS job")
         except ClientError as ex:
-            self.log.error('AWS request failed, check logs for more info: %s', ex)
+            self.log.error("AWS request failed, check logs for more info: %s", ex)
 
         return reason
 
@@ -326,10 +405,10 @@ class EmrContainerHook(AwsBaseHook):
             return response["jobRun"]["state"]
         except self.conn.exceptions.ResourceNotFoundException:
             # If the job is not found, we raise an exception as something fatal has happened.
-            raise AirflowException(f'Job ID {job_id} not found on Virtual Cluster {self.virtual_cluster_id}')
+            raise AirflowException(f"Job ID {job_id} not found on Virtual Cluster {self.virtual_cluster_id}")
         except ClientError as ex:
             # If we receive a generic ClientError, we swallow the exception so that the
-            self.log.error('AWS request failed, check logs for more info: %s', ex)
+            self.log.error("AWS request failed, check logs for more info: %s", ex)
             return None
 
     def poll_query_status(
