@@ -42,7 +42,7 @@ class CloudwatchTaskHandler(FileTaskHandler, LoggingMixin):
 
     def __init__(self, base_log_folder: str, log_group_arn: str, filename_template: str | None = None):
         super().__init__(base_log_folder, filename_template)
-        split_arn = log_group_arn.split(':')
+        split_arn = log_group_arn.split(":")
 
         self.handler = None
         self.log_group = split_arn[6]
@@ -53,18 +53,18 @@ class CloudwatchTaskHandler(FileTaskHandler, LoggingMixin):
     def hook(self):
         """Returns AwsLogsHook."""
         return AwsLogsHook(
-            aws_conn_id=conf.get('logging', 'REMOTE_LOG_CONN_ID'), region_name=self.region_name
+            aws_conn_id=conf.get("logging", "REMOTE_LOG_CONN_ID"), region_name=self.region_name
         )
 
     def _render_filename(self, ti, try_number):
         # Replace unsupported log group name characters
-        return super()._render_filename(ti, try_number).replace(':', '_')
+        return super()._render_filename(ti, try_number).replace(":", "_")
 
     def set_context(self, ti):
         super().set_context(ti)
         self.handler = watchtower.CloudWatchLogHandler(
-            log_group=self.log_group,
-            stream_name=self._render_filename(ti, ti.try_number),
+            log_group_name=self.log_group,
+            log_stream_name=self._render_filename(ti, ti.try_number),
             boto3_client=self.hook.get_conn(),
         )
 
@@ -84,11 +84,21 @@ class CloudwatchTaskHandler(FileTaskHandler, LoggingMixin):
 
     def _read(self, task_instance, try_number, metadata=None):
         stream_name = self._render_filename(task_instance, try_number)
-        return (
-            f'*** Reading remote log from Cloudwatch log_group: {self.log_group} '
-            f'log_stream: {stream_name}.\n{self.get_cloudwatch_logs(stream_name=stream_name)}\n',
-            {'end_of_log': True},
-        )
+        try:
+            return (
+                f"*** Reading remote log from Cloudwatch log_group: {self.log_group} "
+                f"log_stream: {stream_name}.\n{self.get_cloudwatch_logs(stream_name=stream_name)}\n",
+                {"end_of_log": True},
+            )
+        except Exception as e:
+            log = (
+                f"*** Unable to read remote logs from Cloudwatch (log_group: {self.log_group}, log_stream: "
+                f"{stream_name})\n*** {str(e)}\n\n"
+            )
+            self.log.error(log)
+            local_log, metadata = super()._read(task_instance, try_number, metadata)
+            log += local_log
+            return log, metadata
 
     def get_cloudwatch_logs(self, stream_name: str) -> str:
         """
@@ -97,21 +107,15 @@ class CloudwatchTaskHandler(FileTaskHandler, LoggingMixin):
         :param stream_name: name of the Cloudwatch log stream to get all logs from
         :return: string of all logs from the given log stream
         """
-        try:
-            events = list(
-                self.hook.get_log_events(
-                    log_group=self.log_group, log_stream_name=stream_name, start_from_head=True
-                )
-            )
-
-            return '\n'.join(self._event_to_str(event) for event in events)
-        except Exception:
-            msg = f'Could not read remote logs from log_group: {self.log_group} log_stream: {stream_name}.'
-            self.log.exception(msg)
-            return msg
+        events = self.hook.get_log_events(
+            log_group=self.log_group,
+            log_stream_name=stream_name,
+            start_from_head=True,
+        )
+        return "\n".join(self._event_to_str(event) for event in events)
 
     def _event_to_str(self, event: dict) -> str:
-        event_dt = datetime.utcfromtimestamp(event['timestamp'] / 1000.0)
-        formatted_event_dt = event_dt.strftime('%Y-%m-%d %H:%M:%S,%f')[:-3]
-        message = event['message']
-        return f'[{formatted_event_dt}] {message}'
+        event_dt = datetime.utcfromtimestamp(event["timestamp"] / 1000.0)
+        formatted_event_dt = event_dt.strftime("%Y-%m-%d %H:%M:%S,%f")[:-3]
+        message = event["message"]
+        return f"[{formatted_event_dt}] {message}"
