@@ -31,7 +31,7 @@ from airflow.utils.json import AirflowJsonEncoder
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
-DEFAULT_CONN_ID: str = 'aws_default'
+DEFAULT_CONN_ID: str = "aws_default"
 CHECK_INTERVAL_SECOND: int = 30
 
 
@@ -45,15 +45,16 @@ class SageMakerBaseOperator(BaseOperator):
     :param config: The configuration necessary to start a training job (templated)
     """
 
-    template_fields: Sequence[str] = ('config',)
+    template_fields: Sequence[str] = ("config",)
     template_ext: Sequence[str] = ()
-    template_fields_renderers: dict = {'config': 'json'}
-    ui_color: str = '#ededed'
+    template_fields_renderers: dict = {"config": "json"}
+    ui_color: str = "#ededed"
     integer_fields: list[list[Any]] = []
 
-    def __init__(self, *, config: dict, **kwargs):
+    def __init__(self, *, config: dict, aws_conn_id: str = DEFAULT_CONN_ID, **kwargs):
         super().__init__(**kwargs)
         self.config = config
+        self.aws_conn_id = aws_conn_id
 
     def parse_integer(self, config: dict, field: list[str] | str) -> None:
         """Recursive method for parsing string fields holding integer values to integers."""
@@ -86,13 +87,13 @@ class SageMakerBaseOperator(BaseOperator):
     def preprocess_config(self) -> None:
         """Process the config into a usable form."""
         self._create_integer_fields()
-        self.log.info('Preprocessing the config and doing required s3_operations')
+        self.log.info("Preprocessing the config and doing required s3_operations")
         self.hook.configure_s3_resources(self.config)
         self.parse_config_integers()
         self.expand_role()
         self.log.info(
-            'After preprocessing the config is:\n %s',
-            json.dumps(self.config, sort_keys=True, indent=4, separators=(',', ': ')),
+            "After preprocessing the config is:\n %s",
+            json.dumps(self.config, sort_keys=True, indent=4, separators=(",", ": ")),
         )
 
     def _create_integer_fields(self) -> None:
@@ -103,7 +104,7 @@ class SageMakerBaseOperator(BaseOperator):
         self.integer_fields = []
 
     def execute(self, context: Context) -> None | dict:
-        raise NotImplementedError('Please implement execute() in sub class!')
+        raise NotImplementedError("Please implement execute() in sub class!")
 
     @cached_property
     def hook(self):
@@ -147,17 +148,16 @@ class SageMakerProcessingOperator(SageMakerBaseOperator):
         print_log: bool = True,
         check_interval: int = CHECK_INTERVAL_SECOND,
         max_ingestion_time: int | None = None,
-        action_if_job_exists: str = 'increment',
+        action_if_job_exists: str = "increment",
         **kwargs,
     ):
-        super().__init__(config=config, **kwargs)
-        if action_if_job_exists not in ('increment', 'fail'):
+        super().__init__(config=config, aws_conn_id=aws_conn_id, **kwargs)
+        if action_if_job_exists not in ("increment", "fail"):
             raise AirflowException(
                 f"Argument action_if_job_exists accepts only 'increment' and 'fail'. \
                 Provided value: '{action_if_job_exists}'."
             )
         self.action_if_job_exists = action_if_job_exists
-        self.aws_conn_id = aws_conn_id
         self.wait_for_completion = wait_for_completion
         self.print_log = print_log
         self.check_interval = check_interval
@@ -166,35 +166,42 @@ class SageMakerProcessingOperator(SageMakerBaseOperator):
     def _create_integer_fields(self) -> None:
         """Set fields which should be cast to integers."""
         self.integer_fields: list[list[str] | list[list[str]]] = [
-            ['ProcessingResources', 'ClusterConfig', 'InstanceCount'],
-            ['ProcessingResources', 'ClusterConfig', 'VolumeSizeInGB'],
+            ["ProcessingResources", "ClusterConfig", "InstanceCount"],
+            ["ProcessingResources", "ClusterConfig", "VolumeSizeInGB"],
         ]
-        if 'StoppingCondition' in self.config:
-            self.integer_fields.append(['StoppingCondition', 'MaxRuntimeInSeconds'])
+        if "StoppingCondition" in self.config:
+            self.integer_fields.append(["StoppingCondition", "MaxRuntimeInSeconds"])
 
     def expand_role(self) -> None:
         """Expands an IAM role name into an ARN."""
-        if 'RoleArn' in self.config:
-            hook = AwsBaseHook(self.aws_conn_id, client_type='iam')
-            self.config['RoleArn'] = hook.expand_role(self.config['RoleArn'])
+        if "RoleArn" in self.config:
+            hook = AwsBaseHook(self.aws_conn_id, client_type="iam")
+            self.config["RoleArn"] = hook.expand_role(self.config["RoleArn"])
 
     def execute(self, context: Context) -> dict:
         self.preprocess_config()
-        processing_job_name = self.config['ProcessingJobName']
-        if self.hook.find_processing_job_by_name(processing_job_name):
-            raise AirflowException(
-                f'A SageMaker processing job with name {processing_job_name} already exists.'
-            )
-        self.log.info('Creating SageMaker processing job %s.', self.config['ProcessingJobName'])
+        processing_job_name = self.config["ProcessingJobName"]
+        existing_jobs_found = self.hook.count_processing_jobs_by_name(processing_job_name)
+        if existing_jobs_found:
+            if self.action_if_job_exists == "fail":
+                raise AirflowException(
+                    f"A SageMaker processing job with name {processing_job_name} already exists."
+                )
+            elif self.action_if_job_exists == "increment":
+                self.log.info("Found existing processing job with name '%s'.", processing_job_name)
+                new_processing_job_name = f"{processing_job_name}-{existing_jobs_found + 1}"
+                self.config["ProcessingJobName"] = new_processing_job_name
+                self.log.info("Incremented processing job name to '%s'.", new_processing_job_name)
+
         response = self.hook.create_processing_job(
             self.config,
             wait_for_completion=self.wait_for_completion,
             check_interval=self.check_interval,
             max_ingestion_time=self.max_ingestion_time,
         )
-        if response['ResponseMetadata']['HTTPStatusCode'] != 200:
-            raise AirflowException(f'Sagemaker Processing Job creation failed: {response}')
-        return {'Processing': serialize(self.hook.describe_processing_job(self.config['ProcessingJobName']))}
+        if response["ResponseMetadata"]["HTTPStatusCode"] != 200:
+            raise AirflowException(f"Sagemaker Processing Job creation failed: {response}")
+        return {"Processing": serialize(self.hook.describe_processing_job(self.config["ProcessingJobName"]))}
 
 
 class SageMakerEndpointConfigOperator(SageMakerBaseOperator):
@@ -222,24 +229,22 @@ class SageMakerEndpointConfigOperator(SageMakerBaseOperator):
         aws_conn_id: str = DEFAULT_CONN_ID,
         **kwargs,
     ):
-        super().__init__(config=config, **kwargs)
-        self.config = config
-        self.aws_conn_id = aws_conn_id
+        super().__init__(config=config, aws_conn_id=aws_conn_id, **kwargs)
 
     def _create_integer_fields(self) -> None:
         """Set fields which should be cast to integers."""
-        self.integer_fields: list[list[str]] = [['ProductionVariants', 'InitialInstanceCount']]
+        self.integer_fields: list[list[str]] = [["ProductionVariants", "InitialInstanceCount"]]
 
     def execute(self, context: Context) -> dict:
         self.preprocess_config()
-        self.log.info('Creating SageMaker Endpoint Config %s.', self.config['EndpointConfigName'])
+        self.log.info("Creating SageMaker Endpoint Config %s.", self.config["EndpointConfigName"])
         response = self.hook.create_endpoint_config(self.config)
-        if response['ResponseMetadata']['HTTPStatusCode'] != 200:
-            raise AirflowException(f'Sagemaker endpoint config creation failed: {response}')
+        if response["ResponseMetadata"]["HTTPStatusCode"] != 200:
+            raise AirflowException(f"Sagemaker endpoint config creation failed: {response}")
         else:
             return {
-                'EndpointConfig': serialize(
-                    self.hook.describe_endpoint_config(self.config['EndpointConfigName'])
+                "EndpointConfig": serialize(
+                    self.hook.describe_endpoint_config(self.config["EndpointConfigName"])
                 )
             }
 
@@ -300,55 +305,53 @@ class SageMakerEndpointOperator(SageMakerBaseOperator):
         wait_for_completion: bool = True,
         check_interval: int = CHECK_INTERVAL_SECOND,
         max_ingestion_time: int | None = None,
-        operation: str = 'create',
+        operation: str = "create",
         **kwargs,
     ):
-        super().__init__(config=config, **kwargs)
-        self.config = config
-        self.aws_conn_id = aws_conn_id
+        super().__init__(config=config, aws_conn_id=aws_conn_id, **kwargs)
         self.wait_for_completion = wait_for_completion
         self.check_interval = check_interval
         self.max_ingestion_time = max_ingestion_time
         self.operation = operation.lower()
-        if self.operation not in ['create', 'update']:
+        if self.operation not in ["create", "update"]:
             raise ValueError('Invalid value! Argument operation has to be one of "create" and "update"')
 
     def _create_integer_fields(self) -> None:
         """Set fields which should be cast to integers."""
-        if 'EndpointConfig' in self.config:
+        if "EndpointConfig" in self.config:
             self.integer_fields: list[list[str]] = [
-                ['EndpointConfig', 'ProductionVariants', 'InitialInstanceCount']
+                ["EndpointConfig", "ProductionVariants", "InitialInstanceCount"]
             ]
 
     def expand_role(self) -> None:
         """Expands an IAM role name into an ARN."""
-        if 'Model' not in self.config:
+        if "Model" not in self.config:
             return
-        hook = AwsBaseHook(self.aws_conn_id, client_type='iam')
-        config = self.config['Model']
-        if 'ExecutionRoleArn' in config:
-            config['ExecutionRoleArn'] = hook.expand_role(config['ExecutionRoleArn'])
+        hook = AwsBaseHook(self.aws_conn_id, client_type="iam")
+        config = self.config["Model"]
+        if "ExecutionRoleArn" in config:
+            config["ExecutionRoleArn"] = hook.expand_role(config["ExecutionRoleArn"])
 
     def execute(self, context: Context) -> dict:
         self.preprocess_config()
-        model_info = self.config.get('Model')
-        endpoint_config_info = self.config.get('EndpointConfig')
-        endpoint_info = self.config.get('Endpoint', self.config)
+        model_info = self.config.get("Model")
+        endpoint_config_info = self.config.get("EndpointConfig")
+        endpoint_info = self.config.get("Endpoint", self.config)
         if model_info:
-            self.log.info('Creating SageMaker model %s.', model_info['ModelName'])
+            self.log.info("Creating SageMaker model %s.", model_info["ModelName"])
             self.hook.create_model(model_info)
         if endpoint_config_info:
-            self.log.info('Creating endpoint config %s.', endpoint_config_info['EndpointConfigName'])
+            self.log.info("Creating endpoint config %s.", endpoint_config_info["EndpointConfigName"])
             self.hook.create_endpoint_config(endpoint_config_info)
-        if self.operation == 'create':
+        if self.operation == "create":
             sagemaker_operation = self.hook.create_endpoint
-            log_str = 'Creating'
-        elif self.operation == 'update':
+            log_str = "Creating"
+        elif self.operation == "update":
             sagemaker_operation = self.hook.update_endpoint
-            log_str = 'Updating'
+            log_str = "Updating"
         else:
             raise ValueError('Invalid value! Argument operation has to be one of "create" and "update"')
-        self.log.info('%s SageMaker endpoint %s.', log_str, endpoint_info['EndpointName'])
+        self.log.info("%s SageMaker endpoint %s.", log_str, endpoint_info["EndpointName"])
         try:
             response = sagemaker_operation(
                 endpoint_info,
@@ -357,23 +360,23 @@ class SageMakerEndpointOperator(SageMakerBaseOperator):
                 max_ingestion_time=self.max_ingestion_time,
             )
         except ClientError:
-            self.operation = 'update'
+            self.operation = "update"
             sagemaker_operation = self.hook.update_endpoint
-            log_str = 'Updating'
+            log_str = "Updating"
             response = sagemaker_operation(
                 endpoint_info,
                 wait_for_completion=self.wait_for_completion,
                 check_interval=self.check_interval,
                 max_ingestion_time=self.max_ingestion_time,
             )
-        if response['ResponseMetadata']['HTTPStatusCode'] != 200:
-            raise AirflowException(f'Sagemaker endpoint creation failed: {response}')
+        if response["ResponseMetadata"]["HTTPStatusCode"] != 200:
+            raise AirflowException(f"Sagemaker endpoint creation failed: {response}")
         else:
             return {
-                'EndpointConfig': serialize(
-                    self.hook.describe_endpoint_config(endpoint_info['EndpointConfigName'])
+                "EndpointConfig": serialize(
+                    self.hook.describe_endpoint_config(endpoint_info["EndpointConfigName"])
                 ),
-                'Endpoint': serialize(self.hook.describe_endpoint(endpoint_info['EndpointName'])),
+                "Endpoint": serialize(self.hook.describe_endpoint(endpoint_info["EndpointName"])),
             }
 
 
@@ -429,17 +432,15 @@ class SageMakerTransformOperator(SageMakerBaseOperator):
         check_interval: int = CHECK_INTERVAL_SECOND,
         max_ingestion_time: int | None = None,
         check_if_job_exists: bool = True,
-        action_if_job_exists: str = 'increment',
+        action_if_job_exists: str = "increment",
         **kwargs,
     ):
-        super().__init__(config=config, **kwargs)
-        self.config = config
-        self.aws_conn_id = aws_conn_id
+        super().__init__(config=config, aws_conn_id=aws_conn_id, **kwargs)
         self.wait_for_completion = wait_for_completion
         self.check_interval = check_interval
         self.max_ingestion_time = max_ingestion_time
         self.check_if_job_exists = check_if_job_exists
-        if action_if_job_exists in ('increment', 'fail'):
+        if action_if_job_exists in ("increment", "fail"):
             self.action_if_job_exists = action_if_job_exists
         else:
             raise AirflowException(
@@ -450,62 +451,62 @@ class SageMakerTransformOperator(SageMakerBaseOperator):
     def _create_integer_fields(self) -> None:
         """Set fields which should be cast to integers."""
         self.integer_fields: list[list[str]] = [
-            ['Transform', 'TransformResources', 'InstanceCount'],
-            ['Transform', 'MaxConcurrentTransforms'],
-            ['Transform', 'MaxPayloadInMB'],
+            ["Transform", "TransformResources", "InstanceCount"],
+            ["Transform", "MaxConcurrentTransforms"],
+            ["Transform", "MaxPayloadInMB"],
         ]
-        if 'Transform' not in self.config:
+        if "Transform" not in self.config:
             for field in self.integer_fields:
                 field.pop(0)
 
     def expand_role(self) -> None:
         """Expands an IAM role name into an ARN."""
-        if 'Model' not in self.config:
+        if "Model" not in self.config:
             return
-        config = self.config['Model']
-        if 'ExecutionRoleArn' in config:
-            hook = AwsBaseHook(self.aws_conn_id, client_type='iam')
-            config['ExecutionRoleArn'] = hook.expand_role(config['ExecutionRoleArn'])
+        config = self.config["Model"]
+        if "ExecutionRoleArn" in config:
+            hook = AwsBaseHook(self.aws_conn_id, client_type="iam")
+            config["ExecutionRoleArn"] = hook.expand_role(config["ExecutionRoleArn"])
 
     def execute(self, context: Context) -> dict:
         self.preprocess_config()
-        model_config = self.config.get('Model')
-        transform_config = self.config.get('Transform', self.config)
+        model_config = self.config.get("Model")
+        transform_config = self.config.get("Transform", self.config)
         if self.check_if_job_exists:
             self._check_if_transform_job_exists()
         if model_config:
-            self.log.info('Creating SageMaker Model %s for transform job', model_config['ModelName'])
+            self.log.info("Creating SageMaker Model %s for transform job", model_config["ModelName"])
             self.hook.create_model(model_config)
-        self.log.info('Creating SageMaker transform Job %s.', transform_config['TransformJobName'])
+        self.log.info("Creating SageMaker transform Job %s.", transform_config["TransformJobName"])
         response = self.hook.create_transform_job(
             transform_config,
             wait_for_completion=self.wait_for_completion,
             check_interval=self.check_interval,
             max_ingestion_time=self.max_ingestion_time,
         )
-        if response['ResponseMetadata']['HTTPStatusCode'] != 200:
-            raise AirflowException(f'Sagemaker transform Job creation failed: {response}')
+        if response["ResponseMetadata"]["HTTPStatusCode"] != 200:
+            raise AirflowException(f"Sagemaker transform Job creation failed: {response}")
         else:
             return {
-                'Model': serialize(self.hook.describe_model(transform_config['ModelName'])),
-                'Transform': serialize(
-                    self.hook.describe_transform_job(transform_config['TransformJobName'])
+                "Model": serialize(self.hook.describe_model(transform_config["ModelName"])),
+                "Transform": serialize(
+                    self.hook.describe_transform_job(transform_config["TransformJobName"])
                 ),
             }
 
     def _check_if_transform_job_exists(self) -> None:
-        transform_config = self.config.get('Transform', self.config)
-        transform_job_name = transform_config['TransformJobName']
+        transform_config = self.config.get("Transform", self.config)
+        transform_job_name = transform_config["TransformJobName"]
         transform_jobs = self.hook.list_transform_jobs(name_contains=transform_job_name)
-        if transform_job_name in [tj['TransformJobName'] for tj in transform_jobs]:
-            if self.action_if_job_exists == 'increment':
+        if transform_job_name in [tj["TransformJobName"] for tj in transform_jobs]:
+            if self.action_if_job_exists == "increment":
                 self.log.info("Found existing transform job with name '%s'.", transform_job_name)
-                new_transform_job_name = f'{transform_job_name}-{(len(transform_jobs) + 1)}'
-                transform_config['TransformJobName'] = new_transform_job_name
+                new_transform_job_name = f"{transform_job_name}-{(len(transform_jobs) + 1)}"
+                transform_config["TransformJobName"] = new_transform_job_name
                 self.log.info("Incremented transform job name to '%s'.", new_transform_job_name)
-            elif self.action_if_job_exists == 'fail':
+            elif self.action_if_job_exists == "fail":
                 raise AirflowException(
-                    f'A SageMaker transform job with name {transform_job_name} already exists.'
+                    f"A SageMaker transform job with name {transform_job_name} already exists."
                 )
 
 
@@ -545,35 +546,33 @@ class SageMakerTuningOperator(SageMakerBaseOperator):
         max_ingestion_time: int | None = None,
         **kwargs,
     ):
-        super().__init__(config=config, **kwargs)
-        self.config = config
-        self.aws_conn_id = aws_conn_id
+        super().__init__(config=config, aws_conn_id=aws_conn_id, **kwargs)
         self.wait_for_completion = wait_for_completion
         self.check_interval = check_interval
         self.max_ingestion_time = max_ingestion_time
 
     def expand_role(self) -> None:
         """Expands an IAM role name into an ARN."""
-        if 'TrainingJobDefinition' in self.config:
-            config = self.config['TrainingJobDefinition']
-            if 'RoleArn' in config:
-                hook = AwsBaseHook(self.aws_conn_id, client_type='iam')
-                config['RoleArn'] = hook.expand_role(config['RoleArn'])
+        if "TrainingJobDefinition" in self.config:
+            config = self.config["TrainingJobDefinition"]
+            if "RoleArn" in config:
+                hook = AwsBaseHook(self.aws_conn_id, client_type="iam")
+                config["RoleArn"] = hook.expand_role(config["RoleArn"])
 
     def _create_integer_fields(self) -> None:
         """Set fields which should be cast to integers."""
         self.integer_fields: list[list[str]] = [
-            ['HyperParameterTuningJobConfig', 'ResourceLimits', 'MaxNumberOfTrainingJobs'],
-            ['HyperParameterTuningJobConfig', 'ResourceLimits', 'MaxParallelTrainingJobs'],
-            ['TrainingJobDefinition', 'ResourceConfig', 'InstanceCount'],
-            ['TrainingJobDefinition', 'ResourceConfig', 'VolumeSizeInGB'],
-            ['TrainingJobDefinition', 'StoppingCondition', 'MaxRuntimeInSeconds'],
+            ["HyperParameterTuningJobConfig", "ResourceLimits", "MaxNumberOfTrainingJobs"],
+            ["HyperParameterTuningJobConfig", "ResourceLimits", "MaxParallelTrainingJobs"],
+            ["TrainingJobDefinition", "ResourceConfig", "InstanceCount"],
+            ["TrainingJobDefinition", "ResourceConfig", "VolumeSizeInGB"],
+            ["TrainingJobDefinition", "StoppingCondition", "MaxRuntimeInSeconds"],
         ]
 
     def execute(self, context: Context) -> dict:
         self.preprocess_config()
         self.log.info(
-            'Creating SageMaker Hyper-Parameter Tuning Job %s', self.config['HyperParameterTuningJobName']
+            "Creating SageMaker Hyper-Parameter Tuning Job %s", self.config["HyperParameterTuningJobName"]
         )
         response = self.hook.create_tuning_job(
             self.config,
@@ -581,11 +580,11 @@ class SageMakerTuningOperator(SageMakerBaseOperator):
             check_interval=self.check_interval,
             max_ingestion_time=self.max_ingestion_time,
         )
-        if response['ResponseMetadata']['HTTPStatusCode'] != 200:
-            raise AirflowException(f'Sagemaker Tuning Job creation failed: {response}')
+        if response["ResponseMetadata"]["HTTPStatusCode"] != 200:
+            raise AirflowException(f"Sagemaker Tuning Job creation failed: {response}")
         else:
             return {
-                'Tuning': serialize(self.hook.describe_tuning_job(self.config['HyperParameterTuningJobName']))
+                "Tuning": serialize(self.hook.describe_tuning_job(self.config["HyperParameterTuningJobName"]))
             }
 
 
@@ -608,24 +607,22 @@ class SageMakerModelOperator(SageMakerBaseOperator):
     """
 
     def __init__(self, *, config: dict, aws_conn_id: str = DEFAULT_CONN_ID, **kwargs):
-        super().__init__(config=config, **kwargs)
-        self.config = config
-        self.aws_conn_id = aws_conn_id
+        super().__init__(config=config, aws_conn_id=aws_conn_id, **kwargs)
 
     def expand_role(self) -> None:
         """Expands an IAM role name into an ARN."""
-        if 'ExecutionRoleArn' in self.config:
-            hook = AwsBaseHook(self.aws_conn_id, client_type='iam')
-            self.config['ExecutionRoleArn'] = hook.expand_role(self.config['ExecutionRoleArn'])
+        if "ExecutionRoleArn" in self.config:
+            hook = AwsBaseHook(self.aws_conn_id, client_type="iam")
+            self.config["ExecutionRoleArn"] = hook.expand_role(self.config["ExecutionRoleArn"])
 
     def execute(self, context: Context) -> dict:
         self.preprocess_config()
-        self.log.info('Creating SageMaker Model %s.', self.config['ModelName'])
+        self.log.info("Creating SageMaker Model %s.", self.config["ModelName"])
         response = self.hook.create_model(self.config)
-        if response['ResponseMetadata']['HTTPStatusCode'] != 200:
-            raise AirflowException(f'Sagemaker model creation failed: {response}')
+        if response["ResponseMetadata"]["HTTPStatusCode"] != 200:
+            raise AirflowException(f"Sagemaker model creation failed: {response}")
         else:
-            return {'Model': serialize(self.hook.describe_model(self.config['ModelName']))}
+            return {"Model": serialize(self.hook.describe_model(self.config["ModelName"]))}
 
 
 class SageMakerTrainingOperator(SageMakerBaseOperator):
@@ -667,17 +664,16 @@ class SageMakerTrainingOperator(SageMakerBaseOperator):
         check_interval: int = CHECK_INTERVAL_SECOND,
         max_ingestion_time: int | None = None,
         check_if_job_exists: bool = True,
-        action_if_job_exists: str = 'increment',
+        action_if_job_exists: str = "increment",
         **kwargs,
     ):
-        super().__init__(config=config, **kwargs)
-        self.aws_conn_id = aws_conn_id
+        super().__init__(config=config, aws_conn_id=aws_conn_id, **kwargs)
         self.wait_for_completion = wait_for_completion
         self.print_log = print_log
         self.check_interval = check_interval
         self.max_ingestion_time = max_ingestion_time
         self.check_if_job_exists = check_if_job_exists
-        if action_if_job_exists in ('increment', 'fail'):
+        if action_if_job_exists in ("increment", "fail"):
             self.action_if_job_exists = action_if_job_exists
         else:
             raise AirflowException(
@@ -687,23 +683,23 @@ class SageMakerTrainingOperator(SageMakerBaseOperator):
 
     def expand_role(self) -> None:
         """Expands an IAM role name into an ARN."""
-        if 'RoleArn' in self.config:
-            hook = AwsBaseHook(self.aws_conn_id, client_type='iam')
-            self.config['RoleArn'] = hook.expand_role(self.config['RoleArn'])
+        if "RoleArn" in self.config:
+            hook = AwsBaseHook(self.aws_conn_id, client_type="iam")
+            self.config["RoleArn"] = hook.expand_role(self.config["RoleArn"])
 
     def _create_integer_fields(self) -> None:
         """Set fields which should be cast to integers."""
         self.integer_fields: list[list[str]] = [
-            ['ResourceConfig', 'InstanceCount'],
-            ['ResourceConfig', 'VolumeSizeInGB'],
-            ['StoppingCondition', 'MaxRuntimeInSeconds'],
+            ["ResourceConfig", "InstanceCount"],
+            ["ResourceConfig", "VolumeSizeInGB"],
+            ["StoppingCondition", "MaxRuntimeInSeconds"],
         ]
 
     def execute(self, context: Context) -> dict:
         self.preprocess_config()
         if self.check_if_job_exists:
             self._check_if_job_exists()
-        self.log.info('Creating SageMaker training job %s.', self.config['TrainingJobName'])
+        self.log.info("Creating SageMaker training job %s.", self.config["TrainingJobName"])
         response = self.hook.create_training_job(
             self.config,
             wait_for_completion=self.wait_for_completion,
@@ -711,23 +707,23 @@ class SageMakerTrainingOperator(SageMakerBaseOperator):
             check_interval=self.check_interval,
             max_ingestion_time=self.max_ingestion_time,
         )
-        if response['ResponseMetadata']['HTTPStatusCode'] != 200:
-            raise AirflowException(f'Sagemaker Training Job creation failed: {response}')
+        if response["ResponseMetadata"]["HTTPStatusCode"] != 200:
+            raise AirflowException(f"Sagemaker Training Job creation failed: {response}")
         else:
-            return {'Training': serialize(self.hook.describe_training_job(self.config['TrainingJobName']))}
+            return {"Training": serialize(self.hook.describe_training_job(self.config["TrainingJobName"]))}
 
     def _check_if_job_exists(self) -> None:
-        training_job_name = self.config['TrainingJobName']
+        training_job_name = self.config["TrainingJobName"]
         training_jobs = self.hook.list_training_jobs(name_contains=training_job_name)
-        if training_job_name in [tj['TrainingJobName'] for tj in training_jobs]:
-            if self.action_if_job_exists == 'increment':
+        if training_job_name in [tj["TrainingJobName"] for tj in training_jobs]:
+            if self.action_if_job_exists == "increment":
                 self.log.info("Found existing training job with name '%s'.", training_job_name)
-                new_training_job_name = f'{training_job_name}-{(len(training_jobs) + 1)}'
-                self.config['TrainingJobName'] = new_training_job_name
+                new_training_job_name = f"{training_job_name}-{(len(training_jobs) + 1)}"
+                self.config["TrainingJobName"] = new_training_job_name
                 self.log.info("Incremented training job name to '%s'.", new_training_job_name)
-            elif self.action_if_job_exists == 'fail':
+            elif self.action_if_job_exists == "fail":
                 raise AirflowException(
-                    f'A SageMaker training job with name {training_job_name} already exists.'
+                    f"A SageMaker training job with name {training_job_name} already exists."
                 )
 
 
@@ -745,11 +741,9 @@ class SageMakerDeleteModelOperator(SageMakerBaseOperator):
     """
 
     def __init__(self, *, config: dict, aws_conn_id: str = DEFAULT_CONN_ID, **kwargs):
-        super().__init__(config=config, **kwargs)
-        self.config = config
-        self.aws_conn_id = aws_conn_id
+        super().__init__(config=config, aws_conn_id=aws_conn_id, **kwargs)
 
     def execute(self, context: Context) -> Any:
         sagemaker_hook = SageMakerHook(aws_conn_id=self.aws_conn_id)
-        sagemaker_hook.delete_model(model_name=self.config['ModelName'])
-        self.log.info("Model %s deleted successfully.", self.config['ModelName'])
+        sagemaker_hook.delete_model(model_name=self.config["ModelName"])
+        self.log.info("Model %s deleted successfully.", self.config["ModelName"])
