@@ -41,7 +41,7 @@ class GlueJobSensor(BaseSensorOperator):
     :param verbose: If True, more Glue Job Run logs show in the Airflow Task Logs.  (default: False)
     """
 
-    template_fields: Sequence[str] = ('job_name', 'run_id')
+    template_fields: Sequence[str] = ("job_name", "run_id")
 
     def __init__(
         self,
@@ -49,7 +49,7 @@ class GlueJobSensor(BaseSensorOperator):
         job_name: str,
         run_id: str,
         verbose: bool = False,
-        aws_conn_id: str = 'aws_default',
+        aws_conn_id: str = "aws_default",
         **kwargs,
     ):
         super().__init__(**kwargs)
@@ -57,23 +57,23 @@ class GlueJobSensor(BaseSensorOperator):
         self.run_id = run_id
         self.verbose = verbose
         self.aws_conn_id = aws_conn_id
-        self.success_states: list[str] = ['SUCCEEDED']
-        self.errored_states: list[str] = ['FAILED', 'STOPPED', 'TIMEOUT']
+        self.success_states: list[str] = ["SUCCEEDED"]
+        self.errored_states: list[str] = ["FAILED", "STOPPED", "TIMEOUT"]
         self.next_log_token: str | None = None
 
     def poke(self, context: Context):
         hook = GlueJobHook(aws_conn_id=self.aws_conn_id)
-        self.log.info('Poking for job run status :for Glue Job %s and ID %s', self.job_name, self.run_id)
+        self.log.info("Poking for job run status :for Glue Job %s and ID %s", self.job_name, self.run_id)
         job_state = hook.get_job_state(job_name=self.job_name, run_id=self.run_id)
         job_failed = False
 
         try:
             if job_state in self.success_states:
-                self.log.info('Exiting Job %s Run State: %s', self.run_id, job_state)
+                self.log.info("Exiting Job %s Run State: %s", self.run_id, job_state)
                 return True
             elif job_state in self.errored_states:
                 job_failed = True
-                job_error_message = 'Exiting Job %s Run State: %s', self.run_id, job_state
+                job_error_message = "Exiting Job %s Run State: %s", self.run_id, job_state
                 self.log.info(job_error_message)
                 raise AirflowException(job_error_message)
             else:
